<?php
/* $Id: latvian-windows-1257.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/**
 * Latvian language file by Sandis Jrics <sandisj at parks.lv>
 */

$charset = 'windows-1257';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$number_thousands_separator = ' ';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Sv', 'P', 'O', 'T', 'C', 'Pk', 'S');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jn', 'Jl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%m.%Y %H:%M';

$timespanfmt = '%s dienas, %s stundas, %s mintes un %s sekundes';

$strAbortedClients = 'Prtraukts';
$strAccessDeniedExplanation = 'phpMyAdmin minja pieslgties MySQL serverim, un serveris noraidja pieslgumu. Ldzu prbaudiet hostu, lietotjvrdu un paroli config.inc.php fail, un prliecinieties, ka tie atbilst informcijai, ko Jums deva MySQL servera administrators.';
$strAccessDenied = 'Pieeja aizliegta';
$strAction = 'Darbba';
$strAddAutoIncrement = 'Pievienot AUTO_INCREMENT vrtbu';
$strAddConstraints = 'Pievienot ierobeojumus';
$strAddDeleteColumn = 'Pievienot/Dzst laukus (kolonnas)';
$strAddDeleteRow = 'Pievienot/Dzst ierakstu';
$strAddFields = 'Pievienot %s lauku(s)';
$strAddHeaderComment = 'Ievietot virsrakst komentru (\\n atdala rindas)';
$strAddIntoComments = 'Pievienot komentros';
$strAddNewField = 'Pievienot jaunu lauku';
$strAddPrivilegesOnDb = 'Pievienot privilijas uz sekojoo  datubzi';
$strAddPrivilegesOnTbl = 'Pievienot privilijas uz sekojoo tabulu';
$strAddSearchConditions = 'Pievienot meklanas nosacjumus ("where" izteiksmes ermenis):';
$strAddToIndex = 'Pievienot indeksam &nbsp;%s&nbsp;kolonn(u/as)';
$strAddUserMessage = 'Js pievienojt jaunu lietotju.';
$strAddUser = 'Pievienot jaunu lietotju';
$strAdministration = 'Administrcija';
$strAffectedRows = 'Ietekmto rindu skaits:';
$strAfterInsertBack = 'Atgriezties atpaka iepriekj lap';
$strAfterInsertNewInsert = 'Ievietot vl vienu rindu';
$strAfterInsertSame = 'Atgriezties aj lap';
$strAfter = 'Pc %s';
$strAllTableSameWidth = 'rdt visas tabulas vienad platum?';
$strAll = 'Visi';
$strAlterOrderBy = 'Maint datu krtoanas laukus';
$strAnalyzeTable = 'Analizt tabulu';
$strAnd = 'Un';
$strAnIndex = 'Indekss tieka pievienots uz %s';
$strAnyHost = 'Jebkur hosts';
$strAny = 'Jebkur';
$strAnyUser = 'Jebkur lietotjs';
$strApproximateCount = 'Var bt aptuvens skaits. Skatt FAQ 3.11';
$strAPrimaryKey = 'Primr atslga pievienota uz lauka %s';
$strArabic = 'Arbu';
$strArmenian = 'Armu';
$strAscending = 'Augo secb';
$strAtBeginningOfTable = 'Tabulas skum';
$strAtEndOfTable = 'Tabulas beigs';
$strAttr = 'Atribti';
$strAutodetect = 'Noteikt automtiski';
$strAutomaticLayout = 'Automtiskais izvietojums';

$strBack = 'Atpaka';
$strBaltic = 'Baltijas';
$strBeginCut = 'IZGRIEZT NO S VIETAS';
$strBeginRaw = 'RINDAS SKUMS';
$strBinary = 'Binrais';
$strBinaryDoNotEdit = 'Binrais - netiek labots';
$strBinaryLog = 'Binrais log-fails';
$strBinLogEventType = 'Notikuma tips';
$strBinLogInfo = 'Informcija';
$strBinLogName = 'Log-faila nosaukums';
$strBinLogOriginalPosition = 'Oriinl pozcija';
$strBinLogPosition = 'Pozcija';
$strBinLogServerId = 'Servera ID';
$strBookmarkAllUsers = 'Dot ikvienam lietotjam pieeju ai grmatzmei';
$strBookmarkDeleted = 'Ieraksts tika dzsts.';
$strBookmarkLabel = 'Nosaukums';
$strBookmarkQuery = 'Saglabtie SQL vaicjumi';
$strBookmarkThis = 'Saglabt o SQL vaicjumu';
$strBookmarkView = 'Tikai apskatt';
$strBrowse = 'Apskatt';
$strBrowseForeignValues = 'Prlkot rjs vrtbas';
$strBulgarian = 'Bulgru';
$strBzError = 'phpMyAdmin nevarja saarhivt failu d bojta Bz2 paplainjuma aj php versij. Stingri rekomendjam uzstdt <code>$cfg[\'BZipDump\']</code> direktvu phpMyAdmin konfigurcijas fail uz <code>FALSE</code>. Ja vlaties lietot Bz2 kompresijas iespjas, Jums juzliek jaunka php versija. Skatt php bug report %s skkai informcijai.';
$strBzip = 'Arhivts ar bzip';

$strCalendar = 'Kalendrs';
$strCannotLogin = 'Nevar pieslgties MySQL serverim';
$strCantLoad = 'nevar ieldt paplainjumu %s,<br />ldzu prbaudiet PHP konfigurciju';
$strCantLoadRecodeIconv = 'Nevar ieldt iconv vai recode paplainjumu, kas ir nepiecieams rakstzmju konvertcijai, ldzu nokonfigurjiet php, lai vartu lietot os paplainjumus, vai ar atsldziet rakstzmju konvertciju phpMyAdmin konfigurcij.';
$strCantRenameIdxToPrimary = 'Nevar prsaukt indeksu par PRIMARY!';
$strCantUseRecodeIconv = 'Nevar lietot iconv, libiconv vai recode_string funkciju, bet php saka, ka paplainjums ir ieldts. Prbaudiet php konfigurciju.';
$strCardinality = 'Kardinalitte';
$strCaseInsensitive = 'reistrnejtgs';
$strCaseSensitive = 'reistrjtgs';
$strCentralEuropean = 'Centrleiropas';
$strChangeCopyModeCopy = '... paturt veco lietotju.';
$strChangeCopyModeDeleteAndReload = ' ... dzst veco lietotju no lietotju tabulas, un pc tam prldt privilijas.';
$strChangeCopyMode = 'Izveidot jaunu lietotju ar tdm pam privilijm un ...';
$strChangeCopyModeJustDelete = ' ... dzst veco lietotju no lietotju tabulas.';
$strChangeCopyModeRevoke = ' ... atemt vecajam lietotjam visas aktvs privilijas, un pc tam dzst viu.';
$strChangeCopyUser = 'Maint piekuves informciju / Klont lietotju';
$strChangeDisplay = 'Izvlieties, kuru lauku rdt';
$strChange = 'Labot';
$strChangePassword = 'Maint paroli';
$strCharset = 'Kodjums';
$strCharsetOfFile = 'Tabulas kodjums:';
$strCharsetsAndCollations = 'Rakstzmju kodjumi un izkrtojumi';
$strCharsets = 'Rakstzmju kodjumi';
$strCheckAll = 'Iezmt visu';
$strCheckOverhead = 'Iezmt tabulas ar prtriu';
$strCheckPrivsLong = 'Prbaudt privilijas uz datubzi &quot;%s&quot;.';
$strCheckPrivs = 'Prbaudt privilijas';
$strCheckTable = 'Prbaudt tabulu';
$strChoosePage = 'Izvlieties lapu rediganai';
$strColComFeat = 'Rdu kolonnu komentrus';
$strCollation = 'Izkrtojumi';
$strColumnNames = 'Kolonnu nosaukumi';
$strColumnPrivileges = 'Kolonnu specifisks privilijas';
$strCommand = 'Komanda';
$strCommentsForTable = 'KOMENTRI TABULAI';
$strComments = 'Komentri';
$strCompatibleHashing = 'MySQL&nbsp;4.0 savietojams';
$strCompleteInserts = 'Pilnas INSERT izteiksmes';
$strCompression = 'Kompresija';
$strConfigFileError = 'phpMyAdmin nevar nolast konfigurcijas failu!<br />Tas var notikt, ja PHP atrod taj kdu, vai ar nevar atrast so failu.<br />Mginiet izsaukt konfigurcijas failu tiei, klikkinot linku zemk un lasiet PHP pazinojumu par kdm. Vairkum gadjumu kaut kur pietrukst pdia vai semikols.<br />Ja redzat tuku lapu, viss ir krtb.';
$strConfigureTableCoord = 'Ldzu konfigurjiet koordintes tabulai %s';
$strConnectionError = 'Nevar pieslgties: kda konfigurcij.';
$strConnections = 'Konekcijas';
$strConstraintsForDumped = 'Ierobeojumi izmestm tabulm';
$strConstraintsForTable = 'Ierobeojumi tabulai';
$strCookiesRequired = '"Cookies" ir jbt atautiem aiz  punkta.';
$strCopyDatabaseOK = 'Datubze %s tika prkopta uz %s';
$strCopyTable = 'Kopt tabulu uz (datubze<b>.</b>tabula):';
$strCopyTableOK = 'Tabula %s tika prkopta uz %s.';
$strCopyTableSameNames = 'Nevar nokopt tabulu uz viu pau!';
$strCouldNotKill = 'phpMyAdmin nevarja nogalint procesu %s. Iespjams, ka tas jau agrk tika izbeigts.';
$strCreateIndex = 'Izveidot indeksu uz&nbsp;%s&nbsp;laukiem';
$strCreateIndexTopic = 'Izveidot jaunu indeksu';
$strCreate = 'Izveidot';
$strCreateNewDatabase = 'Izveidot jaunu datubzi';
$strCreateNewTable = 'Izveidot jaunu tabulu datubz %s';
$strCreatePage = 'Izveidot jaunu lapu';
$strCreatePdfFeat = 'PDF failu izveide';
$strCreationDates = 'Izveidoanas/Atjaunoanas/Piekuves datumi';
$strCriteria = 'Kritrijs';
$strCroatian = 'Horvtu';
$strCSVOptions = 'CSV opcijas';
$strCyrillic = 'Kirilisks';
$strCzech = 'ehu';
$strCzechSlovak = 'ehu-Slovku';

$strDanish = 'Du';
$strDatabase = 'Datubze';
$strDatabaseEmpty = 'Datubzes nosaukums ir tuks!';
$strDatabaseExportOptions = 'Datubzu eksporta opcijas';
$strDatabaseHasBeenDropped = 'Datubze %s tika izdzsta.';
$strDatabaseNoTable = 'aj datubz nav tabulu!';
$strDatabases = 'Datubzes';
$strDatabasesDropped = '%s datubzes tika veiksmgi dzstas.';
$strDatabasesStats = 'Datubzu statistika';
$strDatabasesStatsDisable = 'Izslgt statistiku';
$strDatabasesStatsEnable = 'Ieslgt statistiku';
$strDatabasesStatsHeavyTraffic = 'Piezme: Datubzes statistikas ieslgana eit var izsaukt palielinto datu apmaiu starp webserveri un MySQL serveri.';
$strData = 'Dati';
$strDataDict = 'Datu vrdnca';
$strDataOnly = 'Tikai dati';
$strDBComment = 'Datubzes komentrs: ';
$strDBCopy = 'Kopt datubzi uz';
$strDbPrivileges = 'Datubu specifisks privilijas';
$strDBRename = 'Prsaukt datubzi par';
$strDbSpecific = 'datubzei specifisks';
$strDefault = 'Noklusts';
$strDefaultValueHelp = 'Noklustajm vrtbm, ldzu ievadiet tikai pau vertbu, bez izsargans ar atpakajo slpsvtru vai pdim, lietojot o formatu: a';
$strDefragment = 'Defragmentt tabulu';
$strDelayedInserts = 'Lietot aizturtos INSERT';
$strDeleteAndFlushDescr = 'Tas ir labkais veids, bet priviliju prldana var paemt zinmu laiku.';
$strDeleteAndFlush = 'Dzst lietotjus, un pc tam prldt privilijas.';
$strDeleted = 'Ieraksts tika dzsts';
$strDeletedRows = 'Ieraksti dzsti:';
$strDelete = 'Dzst';
$strDeleting = 'Dzam %s';
$strDelOld = 'Tekoaj lap ir atsauces uz tabulm, kas vairs neeksist. Vai Js gribat dzst s atsauces?';
$strDescending = 'Dilsto secb';
$strDescription = 'Apraksts';
$strDictionary = 'vrdnca';
$strDisabled = 'Izslgts';
$strDisableForeignChecks = 'Neprbaudt rjs atslgas';
$strDisplayFeat = 'Rdt iespjas';
$strDisplayOrder = 'Attloanas secba:';
$strDisplayPDF = 'Rdt PDF shmu';
$strDoAQuery = 'Izpildt "vaicjumu pc parauga" (aizstjjzme: "%")';
$strDocu = 'Dokumentcija';
$strDoYouReally = 'Vai Js tiem gribat ';
$strDropDatabaseStrongWarning = 'Js taisaties LIKVIDT veselu datubzi!';
$strDrop = 'Likvidt';
$strDropUsersDb = 'Dzst datubzes, kurm ir tdi pai vrdi, k lietotjiem.';
$strDumpingData = 'Dati tabulai';
$strDumpSaved = 'Damps tika saglabts fail %s.';
$strDumpXRows = 'Saglabt %s rindas, skot ar %s.';
$strDynamic = 'dinamisks';

$strEdit = 'Labot';
$strEditPDFPages = 'Labot PDF lapas';
$strEditPrivileges = 'Maint privilijas';
$strEffective = 'Efektvs';
$strEmpty = 'Iztukot';
$strEmptyResultSet = 'MySQL atgrieza tuko rezulttu (0 rindas).';
$strEnabled = 'Ieslgts';
$strEncloseInTransaction = 'Iekaut eksportu transakcij';
$strEnd = 'Beigas';
$strEndCut = 'IZGRIEZT LDZ AI VIETAI';
$strEndRaw = 'RINDAS BEIGAS';
$strEnglish = 'Angu';
$strEnglishPrivileges = ' Piezme: MySQL priviliju apzmjumi tiek rakstti angu valod ';
$strError = 'Kda';
$strEscapeWildcards = 'Aizstjjzmes _ un % jaizsarg ar \ priek, lai izmantotu ts burtiski';
$strEstonian = 'Igauu';
$strExcelEdition = 'Excel redakcija';
$strExcelOptions = 'Excel opcijas';
$strExecuteBookmarked = 'Izpildt iegrmatoto vaicjumu';
$strExplain = 'Izskaidrot SQL';
$strExport = 'Eksports';
$strExtendedInserts = 'Paplaintas INSERT izteiksmes';
$strExtra = 'Ekstras';

$strFailedAttempts = 'Neveiksmgi minjumi';
$strFieldHasBeenDropped = 'Lauks %s tika izdzsts';
$strField = 'Lauks';
$strFieldsEmpty = ' Lauku skaits ir nulle! ';
$strFieldsEnclosedBy = 'Lauki iekauti iek';
$strFieldsEscapedBy = 'Glbjoa (escape) rakstzme ir';
$strFields = 'Lauki';
$strFieldsTerminatedBy = 'Lauki atdalti ar';
$strFileAlreadyExists = 'Fails %s jau eksist uz servera. Ldzu nomainiet faila nosaukumu vai atzmjiet failu prrakstanas opciju.';
$strFileCouldNotBeRead = 'Nevar nolast failu';
$strFileNameTemplate = 'Faila nosaukuma ablons';
$strFileNameTemplateRemember = 'atcerties ablonu';
$strFixed = 'fiksts';
$strFlushPrivilegesNote = 'Piezme: phpMyAdmin saem lietotju privilijas pa taisno no MySQL priviliju tabilm. o tabulu saturs var atirties no privilijm, ko lieto serveris, ja tur tika veikti labojumi. aj gadjum ir nepiecieams %sprldt privilijas%s pirms Js turpint.';
$strFlushTable = 'Atsvaidzint tabulu ("FLUSH")';
$strFormat = 'Formats';
$strFormEmpty = 'Form trkst vrtbu!';
$strFullText = 'Pilni teksti';
$strFunction = 'Funkcija';

$strGenBy = 'Uzenerja';
$strGeneralRelationFeat = 'Galvens relciju pabas';
$strGenTime = 'Izveidoanas laiks';
$strGeorgian = 'Gruznu';
$strGerman = 'Vcu';
$strGlobal = 'globls';
$strGlobalPrivileges = 'Globls privilijas';
$strGlobalValue = 'Globl vrtba';
$strGo = 'Aiziet!';
$strGrantOption = 'Pieirt';
$strGreek = 'Grieu';
$strGzip = 'Arhivts ar gzip';

$strHasBeenAltered = 'tika modificta.';
$strHasBeenCreated = 'tika izveidota.';
$strHaveToShow = 'Izvlieties vismaz vienu kolonnu attloanai';
$strHebrew = 'Ebreju';
$strHexForBinary = 'Lietot heksadecimlo formtu binrajiem laukiem';
$strHomepageOfficial = 'Oficil phpMyAdmin mjaslapa';
$strHome = 'Skumlapa';
$strHostEmpty = 'Hosts nav nordts!';
$strHost = 'Hosts';
$strHungarian = 'Ungru';

$strIcelandic = 'Islandieu';
$strId = 'ID';
$strIdxFulltext = 'Pilni teksti';
$strIgnore = 'Ignort';
$strIgnoreInserts = 'Lietot IGNORE INSERTS';
$strImportFiles = 'Importt failus';
$strIndexes = 'Indeksi';
$strIndexHasBeenDropped = 'Indekss %s tika izdzsts';
$strIndex = 'Indekss';
$strIndexName = 'Indeksa nosaukums&nbsp;:';
$strIndexType = 'Indeksa tips&nbsp;:';
$strIndexWarningMultiple = 'Vairk k viena %s atslga tika izveidota kolonnai `%s`';
$strIndexWarningPrimary = 'PRIMARY un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
$strIndexWarningTable = 'Problmas ar indeksiem tabul `%s`';
$strIndexWarningUnique = 'UNIQUE un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
$strInnodbStat = 'InnoDB statuss';
$strInsecureMySQL = 'Jsu konfigurcijas fails satur iestdjumus (lietotjs "root" bez paroles), kas atbilst noklustajam MySQL privilitajam lietotjam. Jsu MySQL serveris strd ar o noklusto variantu, ir atvrts uzbrukumiem, un Jums tiem jaiztaisa is drobas caurums.';
$strInsertAsNewRow = 'Ievietot k jaunu rindu';
$strInsertedRowId = 'Ievietots rindas id:';
$strInsertedRows = 'Rindas pievienotas:';
$strInsert = 'Pievienot';
$strInternalNotNecessary = '* Iekj relcija nav nepiecieama, kad t eksist ar iek InnoDB.';
$strInternalRelations = 'Iekjs relcijas';
$strInUse = 'lietoan';

$strJapanese = 'Japu';
$strJumpToDB = 'priet pie datubzes &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;Dzstie&quot; lietotji saglab spju piekt serverim k parasti, ldz privilijas tiek prldtas.';
$strJustDelete = 'Dzst lietotjus no priviliju tabulm.';

$strKeepPass = 'Nemaint paroli';
$strKeyname = 'Atslgas nosaukums';
$strKill = 'Nogalint';
$strKorean = 'Korejieu';

$strLandscape = 'Ainava';
$strLatexCaption = 'Tabulas virsraksts';
$strLatexContent = 'Tabulas __TABLE__ saturs';
$strLatexContinuedCaption = 'Tabulas virsraksta turpinjums';
$strLatexContinued = '(turpinjums)';
$strLatexIncludeCaption = 'Iekaut tabulas virsrakstu';
$strLatexLabel = 'Etietes atslga';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX opcijas';
$strLatexStructure = 'Tabulas __TABLE__ struktra';
$strLatvian = 'Latvieu';
$strLengthSet = 'Garums/Vrtbas*';
$strLimitNumRows = 'Rindu skaits vien lap';
$strLinesTerminatedBy = 'Rindas atdaltas ar';
$strLinkNotFound = 'Links nav atrasts';
$strLinksTo = 'Linki uz';
$strLithuanian = 'Lietuvieu';
$strLocalhost = 'Lokls';
$strLocationTextfile = 'Teksta faila atraans vieta';
$strLogin = 'Ieiet';
$strLoginInformation = 'Piekuves informcija';
$strLogout = 'Iziet';
$strLogPassword = 'Parole:';
$strLogServer = 'Serveris';
$strLogUsername = 'Lietotjvrds:';

$strMaximumSize = 'Maksimlais izmrs: %s%s';
$strMIME_available_mime = 'Pieejamie MIME tipi';
$strMIME_available_transform = 'Pieejams transformcijas';
$strMIME_description = 'Apraksts';
$strMIME_MIMEtype = 'MIME tips';
$strMIME_nodescription = 'ai transformcijai nav apraksta.<br />Jautjiet autoram, ko %s dara.';
$strMIME_transformation_note = 'Lai iegtu pieejamo transformciju opcijas un to MIME tipu transformcijas, uzklikiniet uz %stransformciju apraksti%s';
$strMIME_transformation_options_note = 'Ldzu ievadiet transformciju opciju vrtbas, lietojot o formatu: \'a\', 100, b,\'c\'...<br />Ja Jums jlieto atpakaj slpsvtra ("\") vai vienkr pdia ("\'") starp m vrtbm, lieciet ts priek vl vienu atpakajo slpsvtru (piemram \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_transformation_options = 'Transformcijas opcijas';
$strMIME_transformation = 'Prlkprogrammas transformcija';
$strMIMETypesForTable = 'MIME TIPI TABULAI';
$strMIME_without = 'MIME tipiem, kas pardti slprakst, nav atsevias transformcijas funkcijas';
$strModifications = 'Labojumi tika saglabti';
$strModifyIndexTopic = 'Labot indeksu';
$strModify = 'Labot';
$strMoveTableOK = 'Tabula %s tika prvietota uz %s.';
$strMoveTable = 'Prvietot tabulu uz (datubze<b>.</b>tabula):';
$strMoveTableSameNames = 'Nevar prvietot tabulu uz viu pau!';
$strMultilingual = 'daudzvalodu';
$strMySQLCharset = 'MySQL kodjums';
$strMySQLConnectionCollation = 'MySQL konekcijas krtoana';
$strMySQLSaid = 'MySQL teica: ';
$strMySQLShowProcess = 'Pardt procesus';
$strMySQLShowStatus = 'Pardt MySQL izpildes laika informciju';
$strMySQLShowVars = 'Pardt MySQL sistmas maingos';

$strName = 'Nosaukums';
$strNext = 'Nkamie';
$strNoActivity = 'Nebija aktivittes vairk k %s sekunu laik, ldzu autorizjieties vlreiz';
$strNoDatabases = 'Nav datubzu';
$strNoDatabasesSelected = 'Datubze nav izvlta.';
$strNoDescription = 'Bez apraksta';
$strNoDropDatabases = '"DROP DATABASE" komanda ir aizliegta.';
$strNoExplain = 'Neizskaidrot SQL';
$strNoFrames = 'phpMyAdmin ir vairk draudzgs <b>freimu atbalstom</b> prlkprogrammm.';
$strNoIndex = 'Nav definti indeksi!';
$strNoIndexPartsDefined = 'Nav definto indeksa dau!';
$strNoModification = 'Netika labots';
$strNo = 'N';
$strNone = 'Nav';
$strNoOptions = 'im formtam nav opciju';
$strNoPassword = 'Nav paroles';
$strNoPermission = 'Web serverim nav tiesbu rakstt fail %s.';
$strNoPhp = 'Bez PHP koda';
$strNoPrivileges = 'Nav priviliju';
$strNoRights = 'Jums nav pietiekoi tiesbu, lai atrastos eit tagad!';
$strNoRowsSelected = 'Rindas nav iezmtas';
$strNoSpace = 'Nepietiek vietas, lai saglabtu failu %s.';
$strNoTablesFound = 'Tabulas nav atrastas aj datubz.';
$strNoThemeSupport = 'Nav tmu atbalsta, ldzu prbaudiet jsu konfigurciju un/vai Jsu tmas direktorij %s.';
$strNotNumber = 'Tas nav numurs!';
$strNotOK = 'nav OK';
$strNotSet = 'Tabula <b>%s</b> nav atrasta vai nav atzmeta iek %s';
$strNoUsersFound = 'Lietotji netika atrasti.';
$strNoValidateSQL = 'Neprbaudt SQL';
$strNull = 'Nulle';
$strNumSearchResultsInTable = '%s rezultti tabul <i>%s</i>';
$strNumSearchResultsTotal = '<b>Kopum:</b> <i>%s</i> rezultti';
$strNumTables = 'Tabulas';

$strOK = 'Labi';
$strOperations = 'Darbbas';
$strOperator = 'Operators';
$strOptimizeTable = 'Optimizt tabulu';
$strOr = 'Vai';
$strOverhead = 'Prtri';
$strOverwriteExisting = 'Prrakstt eksistjoos failus';

$strPageNumber = 'Lapas numurs:';
$strPaperSize = 'Papra izmrs';
$strPartialText = 'Daji teksti';
$strPasswordChanged = 'Lietotja %s parole tika veiksmgi mainta.';
$strPasswordEmpty = 'Parole nav nordta!';
$strPasswordHashing = 'Paroles jaukana';
$strPasswordNotSame = 'Paroles nesakrt!';
$strPassword = 'Parole';
$strPdfDbSchema = 'Datubzes "%s" shma, %s. lapa';
$strPdfInvalidTblName = 'Tabula "%s" neeksist!';
$strPdfNoTables = 'Nav tabulu';
$strPerHour = 'stund';
$strPerMinute = 'mint';
$strPerSecond = 'sekund';
$strPersian = 'Persieu';
$strPhoneBook = 'telefonu grmata';
$strPHP40203 = 'Js lietojat PHP versiju 4.2.3, kurai ir nopietna kda daudzbaitu rindiu funkcijs (mbstring). Skatt PHP bug report 19404. S PHP versija nav rekomendjama lietoanai ar phpMyAdmin.';
$strPhp = 'Izveidot PHP kodu';
$strPHPVersion = 'PHP Versija';
$strPmaDocumentation = 'phpMyAdmin dokumentcija';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktvai ir JBT nodefintai Jsu konfigurcijas fail!';
$strPolish = 'Pou';
$strPortrait = 'Portrets';
$strPos1 = 'Skums';
$strPrevious = 'Iepriekjie';
$strPrimaryKeyHasBeenDropped = 'Primr atslga tika izdzsta';
$strPrimaryKeyName = 'Primrs atslgas nosaukumam jbt... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>jbt</b> tikai un <b>viengi</b> primrs atslgas indeksa nosaukumam!)';
$strPrimary = 'Primr';
$strPrint = 'Drukt';
$strPrintViewFull = 'Drukas skats (ar pilniem tekstiem)';
$strPrintView = 'Izdrukas versija';
$strPrivDescAllPrivileges = 'Iekauj visas privilijas, izemot GRANT.';
$strPrivDescAlter = 'auj maint esoo tabulu struktru.';
$strPrivDescCreateDb = 'auj veidot jaunas datubzes un tabulas.';
$strPrivDescCreateTbl = 'auj veidot jaunas tabulas.';
$strPrivDescCreateTmpTable = 'auj veidot pagaidu tabulas.';
$strPrivDescDelete = 'auj dzst datus.';
$strPrivDescDropDb = 'auj dzst datubzes un tabulas.';
$strPrivDescDropTbl = 'auj dzst tabulas.';
$strPrivDescExecute = 'auj palaist saglabts procedras; vl nestrd aj MySQL versij.';
$strPrivDescFile = 'auj importt/eksportt datus no/uz failiem.';
$strPrivDescGrant = 'auj pievienot lietotjus un privilijas bez priviliju tabulu prldanas.';
$strPrivDescIndex = 'auj veidot un dzst indeksus.';
$strPrivDescInsert = 'auj ievietot un maint datus.';
$strPrivDescLockTables = 'auj blot tabulas tekoajai darbbai.';
$strPrivDescMaxConnections = 'Ierobeo jauno konekciju skaitu, ko lietotjs var atvrt stundas laik.';
$strPrivDescMaxQuestions = 'Ierobeo vaicjumu skaitu, ko lietotjs var mostt uz serveri stundas laik.';
$strPrivDescMaxUpdates = 'Ierobeo komandu skaitu, kas maina kas maina tabulas vai datubzes, ko lietotjs var izpildt stundas laik.';
$strPrivDescProcess3 = 'auj nogalint citu lietotju procesus.';
$strPrivDescProcess4 = 'auj apskatt pieprasjumu un procesu sarakstus.';
$strPrivDescReferences = 'Nedarbojas aj MySQL versij.';
$strPrivDescReload = 'auj prldt servera iestdjumus un iztukot servera keu.';
$strPrivDescReplClient = 'Dod lietotjam tiesbas jautt, kur ir replikcijas oriinli / kopijas.';
$strPrivDescReplSlave = 'Nepiecieams replikciju kopijm.';
$strPrivDescSelect = 'auj last datus.';
$strPrivDescShowDb = 'Dod pieeju pilnam datubzu sarakstam.';
$strPrivDescShutdown = 'auj apstdint serveri.';
$strPrivDescSuper = 'auj pieslgties pat tad, ja ir sasniegts maksimlais konekciju skaits; Nepiecieams vairumam administratvo operciju, k globlo maingo maia vai citu lietotju procesu nogalinana.';
$strPrivDescUpdate = 'auj maint datus.';
$strPrivDescUsage = 'Nav priviliju.';
$strPrivileges = 'Privilijas';
$strPrivilegesReloaded = 'Privilijas tika veiksmgi prldtas.';
$strProcesses = 'Procesi';
$strProcesslist = 'Procesu saraksts';
$strPutColNames = 'Likt kolonnu nosaukumus pirmaj rind';

$strQBEDel = 'Dzst';
$strQBEIns = 'Ielikt';
$strQBE = 'Vaicjums pc parauga';
$strQueryFrame = 'Vaicjuma logs';
$strQueryOnDb = 'SQL vaicjums uz datubzes <b>%s</b>:';
$strQuerySQLHistory = 'SQL vsture';
$strQueryStatistics = '<b>Pieprasjumu statistika</b>: %s pieprasjumi tika nostti uz serveri kop t palaians bra.';
$strQueryTime = 'Vaicjums ilga %01.4f s';
$strQueryType = 'Vaicjuma tips';
$strQueryWindowLock = 'Neprrakstt o vaicjumu rpus  loga';

$strReceived = 'Saemts';
$strRecords = 'Ieraksti';
$strReferentialIntegrity = 'Prbaudt referencilo integritti:';
$strRefresh = 'Atjaunot';
$strRelationalSchema = 'Relciju shma';
$strRelationNotWorking = 'Papildiespjas darbam ar saisttm tabulm tika izslgtas. Lai uzzintu kpc, klikkiniet %seit%s.';
$strRelationsForTable = 'RELCIJAS TABULAI';
$strRelations = 'Relcijas';
$strRelationView = 'Relciju prskats';
$strReloadingThePrivileges = 'Prldjam privilijas';
$strRemoveSelectedUsers = 'Dzst izvltos lietotjus';
$strRenameDatabaseOK = 'Datubze %s tika prsaukta par %s';
$strRenameTableOK = 'Tabula %s tika prsaukta par %s';
$strRenameTable = 'Prsaukt tabulu uz';
$strRepairTable = 'Restaurt tabulu';
$strReplaceNULLBy = 'Aizvietot NULL ar';
$strReplaceTable = 'Aizvietot tabulas datus ar datiem no faila';
$strReset = 'Atcelt';
$strResourceLimits = 'Resursu ierobeojumi';
$strReType = 'Atkrtojiet';
$strRevokeAndDelete = 'Atemt visas aktvs privilijas lietotjiem, un pc tam dzst tos.';
$strRevokeAndDeleteDescr = 'Lietotji saglab iespeju lietot datubzes, ldz privilijas tiek prldtas.';
$strRevoke = 'Atsaukt';
$strRevokeMessage = 'Js atmt privilgijas lietotjam %s';
$strRomanian = 'Rumu';
$strRowLength = 'Rindas garums';
$strRowsFrom = 'rindas skot no';
$strRowSize = ' Rindas izmrs ';
$strRowsModeFlippedHorizontal = 'horizontl (pagriezti virsraksti)';
$strRowsModeHorizontal = 'horizontl';
$strRowsModeOptions = '%s skat un atkrtot virsrakstus ik pc %s rindm';
$strRowsModeVertical = 'vertikl';
$strRows = 'Rindas';
$strRowsStatistic = 'Rindas statistika';
$strRunning = 'atrodas uz %s';
$strRunQuery = 'Izpildt vaicjumu';
$strRunSQLQuery = 'Izpildt SQL vaicjumu(s) uz datubzes %s';
$strRussian = 'Krievu';

$strSaveOnServer = 'Saglabt uz servera direktorij %s';
$strSave = 'Saglabt';
$strScaleFactorSmall = 'Mrogoanas faktors ir prk mazs, lai shma ietilptu vien lap';
$strSearchFormTitle = 'Meklt datubz';
$strSearchInTables = 'Tabul(s):';
$strSearch = 'Meklt';
$strSearchNeedle = 'Vrdi vai vrtbas meklanai (aizstjjzme: "%"):';
$strSearchOption1 = 'kaut viens no vrdiem';
$strSearchOption2 = 'visi vrdi';
$strSearchOption3 = 'precza frze';
$strSearchOption4 = 'k regulr izteiksme';
$strSearchResultsFor = 'Meklanas rezultti "<i>%s</i>" %s:';
$strSearchType = 'Atrast:';
$strSecretRequired = 'Konfigurcijas fails tagad prasa slepeno paroli (blowfish_secret).';
$strSelectADb = 'Ldzu izvlieties datubzi';
$strSelectAll = 'Iezmt visu';
$strSelectBinaryLog = 'Izvlieties binro log-failu apskatei';
$strSelectFields = 'Izvlieties laukus (kaut vienu):';
$strSelectNumRows = 'vaicjum';
$strSelectTables = 'Izvlieties tabulas';
$strSend = 'Saglabt k failu';
$strSent = 'Nostts';
$strServerChoice = 'Servera izvle';
$strServerNotResponding = 'Serveris neatbild';
$strServer = 'Serveris';
$strServerStatus = 'Izpildes laika informcija';
$strServerStatusUptime = 'is MySQL serveris strd %s. Tas tika palaists %s.';
$strServerTabVariables = 'Maingie';
$strServerTrafficNotes = '<b>Servera trafiks</b>: s tabulas parda  MySQL servera tkla trafika statistiku kop t palaianas.';
$strServerVars = 'Servera maingie un konfigurcija';
$strServerVersion = 'Servera versija';
$strSessionValue = 'Sesijas vrtba';
$strSetEnumVal = 'Ja lauka tips ir "enum" vai "set", ldzu ievadiet vrtbas atbilstoi im formatam: \'a\',\'b\',\'c\'...<br />Ja Jums vajag ielikt atpakajo slpsvtru (\) vai vienkro pdiu (\') kd no m vrtbm, lieciet ts priek atpakajo slpsvtru (piemram, \'\\\\xyz\' vai \'a\\\'b\').';
$strShowAll = 'Rdt visu';
$strShowColor = 'Rdt krsas';
$strShowDatadictAs = 'Datu vrdncas formats';
$strShowFullQueries = 'Rdt pilnos vaicjumus';
$strShowGrid = 'Rdt rei';
$strShowingRecords = 'Pardu rindas';
$strShowPHPInfo = 'Pardt PHP informciju';
$strShow = 'Rdt';
$strShowTableDimension = 'Rdit tabulu izmrus';
$strShowTables = 'Rdt tabulas';
$strShowThisQuery = ' Rdt o vaicjumu eit atkal ';
$strSimplifiedChinese = 'Vienkrota nieu';
$strSingly = '(atsevii)';
$strSize = 'Izmrs';
$strSlovak = 'Slovku';
$strSlovenian = 'Slovu';
$strSortByKey = 'Krtot pc atslgas';
$strSort = 'Krtoana';
$strSpaceUsage = 'Diska vietas lietoana';
$strSpanish = 'Spu';
$strSplitWordsWithSpace = 'Vrdi ir atdalti ar tukumu (" ").';
$strSQLExportType = 'Eksporta veids';
$strSQLOptions = 'SQL opcijas';
$strSQLParserBugMessage = 'Iespjams, ka Js esat atradui kdu SQL interpretator. Ldzu apskatiet Jsu vaicjumu citgk, un prbaudiet, ka pdias ir pareizas un nav sajauktas. Cits kdas iemesls var bt tas, ka Js atstjt failu ar binro vrtbu rpus pdis iekaut teksta lauka. Js varat ar izmint savu vaicjumu MySQL komandrindas interfeis. MySQL servera kdas paziojums zemk, ja tds ir, var ar paldzt Jums diagnostict problmu. Ja problma paliek, vai ar iek phpMyAdmin kda ir, bet komandrind nav, ldzu samaziniet Jsu SQL vaicjumu ldz vienkram vaicjumam kas izsauc problmas, un atstiet mums ziojumu par kdu, iekaujot taj datus no IZGRIEZT sekcijas zemk:';
$strSQLParserUserError = 'Izkats, ka Jsu SQL vaicajum ir kda. MySQL servera kdas pazinojums zemk, ja tds ir, var ar paldzet Jums diagnostict problmu.';
$strSQLQuery = 'SQL vaicjums';
$strSQLResult = 'SQL rezultts';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Nedergs identifikators';
$strSQPBugUnclosedQuote = 'Neaizvrtas pdias';
$strSQPBugUnknownPunctuation = 'Nezinm punktucijas zme';
$strStatCheckTime = 'Pdj prbaude';
$strStatCreateTime = 'Izveidoana';
$strStatement = 'Parametrs';
$strStatUpdateTime = 'Pdj atjaunoana';
$strStatus = 'Statuss';
$strStrucCSV = 'CSV dati';
$strStrucData = 'Struktra un dati';
$strStrucExcelCSV = 'CSV dati MS Excel formt';
$strStrucNativeExcel = 'Dati MS Excel format';
$strStrucOnly = 'Tikai struktra';
$strStructPropose = 'Ieteikt tabulas sruktru';
$strStructure = 'Struktra';
$strSubmit = 'Nostt';
$strSuccess = 'Jsu SQL vaicjums tika veiksmgi izpildts';
$strSum = 'Kopum';
$strSwedish = 'Zviedru';
$strSwitchToDatabase = 'Prslgties uz nokopto datubzi';
$strSwitchToTable = 'Prslgties uz nokopto tabulu';

$strTableComments = 'Komentrs tabulai';
$strTableEmpty = 'Tabulas nosaukums nav nordts!';
$strTableHasBeenDropped = 'Tabula %s tika izdzsta';
$strTableHasBeenEmptied = 'Tabula %s tika iztukota';
$strTableHasBeenFlushed = 'Tabula %s tika atsvaidzinta';
$strTableMaintenance = 'Tabulas apkalpoana';
$strTableOfContents = 'Satura rdtjs';
$strTableOptions = 'Tabulas opcijas';
$strTables = '%s tabula(s)';
$strTableStructure = 'Tabulas struktra tabulai';
$strTable = 'Tabula';
$strTakeIt = 'izmantot o stilu';
$strTblPrivileges = 'Tabulu specifisks privilijas';
$strTextAreaLength = ' Sava garuma d,<br /> is lauks var bt neredijams ';
$strThai = 'Taizemieu';
$strTheme = 'Tma / Stils';
$strThisHost = 'is hosts';
$strThreadSuccessfullyKilled = 'Process %s tika veiksmgi nogalints.';
$strTime = 'Laiks';
$strToggleScratchboard = 'pardt/noslpt piezmju tafeli';
$strTotal = 'kop';
$strTotalUC = 'Kop';
$strTraditionalChinese = 'Tradicionla nieu';
$strTraditionalSpanish = 'Tradicionl spu';
$strTraffic = 'Datu apmaia';
$strTransformation_application_octetstream__download = 'Rdt saiti uz lauka binro datu lejupldi. Pirm opcija ir binr faila nosaukums. Otr opcija ir iespjamais lauka nosaukums tabulas rind, kas satur faula nosaukumu. Ja izmantojat otro opciju, pirmo atstjiet tuko.';
$strTransformation_image_jpeg__inline = 'Parda klikinmo sktlu; opcijas: platums, augstums pikseos (saglabjot oriinls proporcijas)';
$strTransformation_image_jpeg__link = 'Parda linku uz o attlu (tiea blob lauka lajuplde).';
$strTransformation_image_png__inline = 'Skatties image/jpeg: k ierindotu attlu';
$strTransformation_text_plain__external = 'Tikai LINUX: Palai rjo aplikciju un padod lauka datus ts standartievad. Atgrie aplikcijas standartizvadi. Noklusjums ir Tidy, kas izskaistina HTML kodu. Drobas apsvrumu d, nepiecieams manuli redit failu libraries/transformations/text_plain__external.inc.php un ielikt rkus, kurus Js ataujat palaist. Pirm opcija ir programmas numurs, ko Js vlaties lietot, otr opcija ir parametri ai programmai. Tre opcija, ja ir vienda ar 1, konvert izvadi, izmantojot htmlspecialchars() (noklusjums ir 1). Ceturtais parametrs, ja viends ar 1, liek NOWRAP parametru satura nai, t k izvade tiks attlota bez prformatanas. (noklusjums ir 1)';
$strTransformation_text_plain__formatted = 'Saglab lauka oriinlo formatjumu. Specilo rakstzmju pasargana netiek veikta.';
$strTransformation_text_plain__imagelink = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir platums pikseos, tre ir augstums.';
$strTransformation_text_plain__link = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir linka nosaukums.';
$strTransformation_text_plain__substr = 'Parda tikai virknes dau. Pirm opcija ir nobde, kas nosaka, kur Jsu teksts skas (noklusjums 0). Otr opcija ir atgrieam teksta garums. Ja tuka, atgrie visu atlikuo tekstu. Tre opcija nosaka rakstzmes, kas tiks pievienotas apgriezts virknes gal (noklusjums: ...) .';
$strTruncateQueries = 'Ierobeot pardto vaicjumu garumu';
$strTurkish = 'Turku';
$strType = 'Tips';

$strUkrainian = 'Ukraiu';
$strUncheckAll = 'Neiezmt neko';
$strUnicode = 'Unikods';
$strUnique = 'Uniklais';
$strUnknown = 'nazinma';
$strUnselectAll = 'Neiezmt neko';
$strUpdatePrivMessage = 'Js modificjt privilijas objektam %s.';
$strUpdateProfileMessage = 'Profils tika modificts.';
$strUpdateQuery = 'Atjaunot vaicjumu';
$strUpdComTab = 'Ldzu skatieties dokumentciju par to, k atjaunot \'Column_comments\' tabulu';
$strUpgrade = 'Jums ir juzliek %s %s vai jaunks.';
$strUsage = 'Aizem';
$strUseBackquotes = 'Lietot apostrofa simbolu [`] tabulu un lauku nosaukumiem';
$strUseHostTable = 'Lietot hostu tabulu';
$strUserAlreadyExists = 'Lietotjs %s jau eksist!';
$strUserEmpty = 'Lietotja vrds nav nordts!';
$strUser = 'Lietotjs';
$strUserName = 'Lietotjvrds';
$strUserNotFound = 'Izvltais lietotjs nav atrasts priviliju tabul.';
$strUserOverview = 'Lietotju prskats';
$strUsersDeleted = 'Izvltie lietotji tika veiksmgi dzsti.';
$strUsersHavingAccessToDb = 'Lietotji, kam ir pieja datubzei &quot;%s&quot;';
$strUseTabKey = 'Lietojiet TAB taustiu, lai prvietotos no vrtbas ldz vrtbai, vai CTRL+bultias, lai prvietotos jebkur viet';
$strUseTables = 'Lietot tabulas';
$strUseTextField = 'Lietot teksta lauku';
$strUseThisValue = 'Lietot o vrtbu';

$strValidateSQL = 'Prbaudt SQL';
$strValidatorError = 'Nevar inicializt SQL prbaudtju. Ldzu prbaudiet, vai esat uzinstaljui nepiecieamos PHP paplainjumus, k aprakstts %sdokumentcij%s.';
$strValue = 'Vrtba';
$strVar = 'Maingais';
$strViewDump = 'Apskatt tabulas dampu (shmu)';
$strViewDumpDatabases = 'Apskatt datubzu dampu (shmu)';
$strViewDumpDB = 'Apskatt datubzes dampu (shmu)';

$strWebServerUploadDirectoryError = 'Direktoija, kuru nordijt augupieldei, nav pieejama';
$strWebServerUploadDirectory = 'web servera augupieldes direktorija';
$strWelcome = 'Laipni lgti %s';
$strWestEuropean = 'Rietumeiropas';
$strWildcard = 'aizstjjzme';
$strWindowNotFound = 'Neizdevs atjaunot galveno prlkprogramas logu. Varbt esat viu aizvrui, vai ar Jsu prlkprogramma bloe starplogu saskarsmi Jsu drobas iestdjumu d.';
$strWithChecked = 'Ar iezmto:';
$strWrongUser = 'Kdains lietotjvrds/parole. Pieeja aizliegta.';

$strXML = 'XML';

$strYes = 'J';

$strZeroRemovesTheLimit = 'Piezme: o opciju uzstdana uz 0 (nulli) atce ierobeojumus.';
$strZip = 'Arhivts ar zip';

// To translate:
$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strAndThen = 'and then';  //to translate

$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strBrowseDistinctValues = 'Browse distinct values';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
$strCopy = 'Copy';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strCSV = 'CSV';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate

$strDataPages = 'Pages containing data';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate

$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strEngines = 'Engines';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strEsperanto = 'Esperanto';  //to translate

$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
$strFileNameTemplateDescriptionServer = 'server name';  //to translate
$strFileNameTemplateDescriptionTable = 'table name';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strFileToImport = 'File to import';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strFreePages = 'Free pages';  //to translate

$strGenerate = 'Generate';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate

$strHandler = 'Handler';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate

$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strImport = 'Import';  //to translate
$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate

$strJoins = 'Joins';  //to translate

$strKeyCache = 'Key cache';  //to translate

$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate

$strMaxConnects = 'max. concurrent connections';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMysqlClientVersion = 'MySQL client version';  //to translate

$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate

$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate

$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strPDFOptions = 'PDF options';  //to translate
$strPDF = 'PDF';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strProtocolVersion = 'Protocol version';  //to translate

$strQueryCache = 'Query cache';  //to translate

$strReadRequests = 'Read requests';  //to translate
$strReloadPrivileges = 'Reload privileges';  //to translate
$strReplication = 'Replication';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate

$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strSorting = 'Sorting';  //to translate
$strSQLCompatibility = 'SQL compatibility mode';  //to translate
$strSQLImportOptions = 'SQL options';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate

$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
$strThemeNotFound = 'Theme %s not found!';  //to translate
$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strThreads = 'Threads';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strUsedPhpExtensions = 'Used PHP extensions';  //to translate

$strVersionInformation = 'Version information';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
$strView = 'View';  //to translate

$strWriteRequests = 'Write requests';  //to translate

$strQueryResultsOperations = 'Query results operations';  //to translate
$strAddClause = 'Add %s';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
$strXMLOptions = 'XML options';  //to translate
$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
$strCreateUserDatabase = 'Database for user';  //to translate
$strCreateUserDatabaseNone = 'None';  //to translate
$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
$strOpenDocumentText = 'Open Document Text';  //to translate
$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
$strInvalidTableName = 'Invalid table name';  //to translate
$strInvalidDatabase = 'Invalid database';  //to translate
$strServers = 'Servers';  //to translate
$strDelimiter = 'Delimiter';  //to translate
$strFunctions = 'Functions';  //to translate
$strProcedures = 'Procedures';  //to translate
$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
$strFontSize = 'Font size';  //to translate
$strLanguage = 'Language';  //to translate
$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strDocSQLOptions = 'DocSQL options';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
